==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/ar_SA/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'تهيئة محلية';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'القوالب';
$lang['locfiledit_onglet_lang'] = 'اللغة';
$lang['locfiledit_onglet_plug'] = 'مساعد شخصي';
$lang['locfiledit_cant_save'] = 'الملف المحلي قابل او غير غابر للكتابه ، تأكد من الوصول و الكتابة الى المجلد"include/"';
$lang['locfiledit_newfile'] = 'الملف غير موجود ، سوف يتم إنشاءه عن طريق تحرير الملفات المحلي';
$lang['locfiledit_save_config'] = 'تمت كتابة الملف بنجاح .';
$lang['locfiledit_show_default'] = 'عرض مرجع الملف :  ';
$lang['locfiledit_save_bak'] = 'نسخة احتياطية أنشأت عن طريق الحفظ ';
$lang['locfiledit_saved_bak'] = ' (%s) تم إنشاء  نسخة احتياطية من الملف';
$lang['locfiledit_save_file'] = 'حفظ الملف ';
$lang['locfiledit_choose_file'] = 'حدد ملف لتحريره ';
$lang['locfiledit_edit'] = 'تحرير';
$lang['locfiledit_restore'] = 'استعادة من  النسخة الاحتياطية';
$lang['locfiledit_restore_confirm'] = 'نجرو التأكيد؟استعادة الملف كي يتم الحفظ في ملفات تالية';
$lang['locfiledit_bak_loaded1'] = 'تم تحميل التخسة الاحتياطية';
$lang['locfiledit_bak_loaded2'] = 'يجب حفظه ليتم استعادته ';
$lang['locfiledit_syntax_error'] = 'خطأ في تركيب الجمل ، لا / يمكن حفظ المف';
$lang['locfiledit_enable_editarea'] = 'تمكين المحرر';
$lang['locfiledit_disable_editarea'] = 'تعطيل المحرر';
$lang['locfiledit_new_tpl'] = 'أنشأ ملف جديد';
$lang['locfiledit_new_filename'] = 'أسم الملف';
$lang['locfiledit_model'] = 'نموذج';
$lang['locfiledit_empty_page'] = 'صفحة فارغه';
$lang['locfiledit_parent_directory'] = 'أصل الدليل';
$lang['locfiledit_filename_error'] = 'الحروف الغير مسموح بها في أسم الملف ';
$lang['locfiledit_file_already_exists'] = 'الملف الموجود';
$lang['locfiledit_model_error'] = 'يجب أختيار نموذج';
$lang['locfiledit_empty_filename'] = 'يجب كتابة أسم الملف';
$lang['locfiledit_webmaster_only'] = 'فقط مدير الموقع يمكن استخدام محرر الملفات المحلي';

?>

==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/ar_SA/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'تهيئة محلية';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'القوالب';
$lang['locfiledit_onglet_lang'] = 'اللغة';
$lang['locfiledit_onglet_plug'] = 'مساعد شخصي';
$lang['locfiledit_cant_save'] = 'الملف المحلي قابل او غير غابر للكتابه ، تأكد من الوصول و الكتابة الى المجلد"include/"';
$lang['locfiledit_newfile'] = 'الملف غير موجود ، سوف يتم إنشاءه عن طريق تحرير الملفات المحلي';
$lang['locfiledit_save_config'] = 'تمت كتابة الملف بنجاح .';
$lang['locfiledit_show_default'] = 'عرض مرجع الملف :  ';
$lang['locfiledit_save_bak'] = 'نسخة احتياطية أنشأت عن طريق الحفظ ';
$lang['locfiledit_saved_bak'] = ' (%s) تم إنشاء  نسخة احتياطية من الملف';
$lang['locfiledit_save_file'] = 'حفظ الملف ';
$lang['locfiledit_choose_file'] = 'حدد ملف لتحريره ';
$lang['locfiledit_edit'] = 'تحرير';
$lang['locfiledit_restore'] = 'استعادة من  النسخة الاحتياطية';
$lang['locfiledit_restore_confirm'] = 'نجرو التأكيد؟استعادة الملف كي يتم الحفظ في ملفات تالية';
$lang['locfiledit_bak_loaded1'] = 'تم تحميل التخسة الاحتياطية';
$lang['locfiledit_bak_loaded2'] = 'يجب حفظه ليتم استعادته ';
$lang['locfiledit_syntax_error'] = 'خطأ في تركيب الجمل ، لا / يمكن حفظ المف';
$lang['locfiledit_new_tpl'] = 'أنشأ ملف جديد';
$lang['locfiledit_new_filename'] = 'أسم الملف';
$lang['locfiledit_model'] = 'نموذج';
$lang['locfiledit_empty_page'] = 'صفحة فارغه';
$lang['locfiledit_parent_directory'] = 'أصل الدليل';
$lang['locfiledit_filename_error'] = 'الحروف الغير مسموح بها في أسم الملف ';
$lang['locfiledit_file_already_exists'] = 'الملف الموجود';
$lang['locfiledit_model_error'] = 'يجب أختيار نموذج';
$lang['locfiledit_empty_filename'] = 'يجب كتابة أسم الملف';
$lang['locfiledit_webmaster_only'] = 'فقط مدير الموقع يمكن استخدام محرر الملفات المحلي';
?>
